@@ -2,15 +2,17 @@
 #this repository contains the full copyright notices and license terms.
 {
     'name' : 'Google Maps',
+    'name_bg_BG': 'Google карти',
     'name_de_DE': 'Google Maps',
     'name_es_CO': 'Mapas de Google',
     'name_es_ES': 'Mapas de Google',
     'name_fr_FR': 'Cartes Google',
-    'version' : '1.8.0',
+    'version' : '2.0.0',
     'author' : 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
     'description': 'Add link from addresses to Google Maps',
+    'description_bg_BG': 'Добавя връзка към адрес от Google карти.',
     'description_de_DE': 'Fügt einen Link für den automatischen Aufruf von Google Maps zu Adressen hinzu.',
     'description_es_CO': 'Añade un enlace a la dirección en Google Maps',
     'description_es_ES': 'Añade un enlace de la dirección a Google Maps',
@@ -23,6 +25,7 @@
         'address.xml',
     ],
     'translation': [
+        'bg_BG.csv',
         'de_DE.csv',
         'es_CO.csv',
         'es_ES.csv',
